@@ -20,6 +20,6 @@
 #ifndef _STARTAPP4HTML_H
 #define _STARTAPP4HTML_H
 
-int startapp4html( int argc, char * argv[], char *prog_name, char *prog_ver );
+int startapp4html( int argc, char * argv[] );
 
 #endif /* _STARTAPP4HTML_H */
