@@ -49,16 +49,35 @@ TagDecorator::startTAG( char *tag, char *attr, char *val ) const
 {
   (*sout) << "<" << tag ;
   if ( attr && val )
-    (*sout) << " " << attr << "=" << val ;
+    generateAttrVal ();
   (*sout) << ">" ;
 }
 
+void
+TagDecorator::generateAttrVal() const
+{
+  (*sout) << " " << attr << "=" << val ;
+}
+
 void
 TagDecorator::endTAG( char *tag ) const
 {
   (*sout) << "</" << tag << ">" ;
 }
 
+// XhtmlTagDecorator
+XhtmlTagDecorator::XhtmlTagDecorator( TextGenerator *t, CharTranslator *ct, 
+                                      char *ta, char *a, char *v ) :
+  TagDecorator (t, ct, ta, a, v)
+{
+}
+
+void
+XhtmlTagDecorator::generateAttrVal() const
+{
+  (*sout) << " style=\"" << attr << ": " << val << "\"";
+}
+
 // ColorDecorator
 ColorDecorator::ColorDecorator( TextGenerator *t, CharTranslator *tr,
                                 char *color ) :
@@ -66,6 +85,13 @@ ColorDecorator::ColorDecorator( TextGenerator *t, CharTranslator *tr,
 {
 }
 
+// XhtmlColorDecorator
+XhtmlColorDecorator::XhtmlColorDecorator( TextGenerator *t, CharTranslator *tr,
+                                          char *color ) :
+  XhtmlTagDecorator( t, tr, SPAN_TAG, COLOR_TAG, color )
+{
+}
+
 // SpanDecorator
 SpanDecorator::SpanDecorator( TextGenerator *t, CharTranslator *tr, char *ta) :
   TextDecorator( t, tr ), span(ta)
