@@ -36,6 +36,7 @@ class TagDecorator : public TextDecorator
  public:
   TagDecorator( TextGenerator *t, CharTranslator *, 
                 char *ta, char *a = 0, char *v = 0 );
+  virtual ~TagDecorator() {}
   
   virtual void startDecorate();
   virtual void endDecorate();
@@ -43,14 +44,31 @@ class TagDecorator : public TextDecorator
  protected:
   void startTAG( char *tag, char *attr, char *val ) const;
   void endTAG( char *tag ) const;
+  virtual void generateAttrVal() const;
 } ;
 
+class XhtmlTagDecorator : public TagDecorator
+{
+ public:
+  XhtmlTagDecorator( TextGenerator *t, CharTranslator *, 
+                     char *ta, char *a, char *v );
+
+ protected:
+  virtual void generateAttrVal() const;
+};
+
 class ColorDecorator : public TagDecorator
 {
  public:
   ColorDecorator( TextGenerator *t, CharTranslator *, char *color );
 } ;
 
+class XhtmlColorDecorator : public XhtmlTagDecorator
+{
+ public:
+  XhtmlColorDecorator( TextGenerator *t, CharTranslator *, char *color );
+};
+
 class SpanDecorator : public TextDecorator
 {
  protected:
