@@ -1,7 +1,7 @@
 #ifndef _FILEUTIL_H
 #define _FILEUTIL_H
 
-#include <istream.h>
+#include <iostream.h>
 
 char *read_file(char *fileName);
 char *createOutputFileName( char *inputFileName, char *outputDir );
