@@ -47,6 +47,7 @@ extern int cpp_scanner_lex() ;
 extern int prolog_scanner_lex() ;
 extern int perl_scanner_lex() ;
 extern int php3_scanner_lex() ;
+extern int python_scanner_lex() ;
 
 extern int tabSpaces; // FIXME
 
@@ -56,7 +57,7 @@ static void _generateln( const char *s );
 static char *get_input_file_name(char *file_name);
 
 void
-processFile( char *source_language,
+processFile( char *source_language, char *output_format,
              char *inputFileName, char *outputFileName, char *docTitle, 
              const char *docHeader, const char *docFooter,
              short entire_doc, char *cssUrl )
@@ -120,7 +121,10 @@ processFile( char *source_language,
   }
   
   if ( entire_doc ) {
-    print_top( docTitle, cssUrl, docHeader, inputFileName );
+    if (strcmp (output_format, "xhtml") == 0)
+      print_xtop( docTitle, cssUrl, docHeader, inputFileName );
+    else
+      print_top( docTitle, cssUrl, docHeader, inputFileName );
   }
 
   printMessage( "translating source code... ", cerr ) ;
@@ -141,6 +145,8 @@ processFile( char *source_language,
     perl_scanner_lex ();
   else if (strcmp (source_language, "php3") == 0)
     php3_scanner_lex ();
+  else if (strcmp (source_language, "python") == 0)
+    python_scanner_lex ();
   else
     {
       cerr << PACKAGE << ": ";
@@ -154,8 +160,12 @@ processFile( char *source_language,
 
   printMessage( "done !", cerr ) ;
   
-  if ( entire_doc )
-    print_bottom( docFooter ) ;
+  if ( entire_doc ) {
+    if (strcmp (output_format, "xhtml") == 0)
+      print_xbottom( docFooter ) ;
+    else
+      print_bottom( docFooter ) ;
+  }
 
   if ( deleteOStream )
     delete sout ;
@@ -203,7 +213,7 @@ print_top( char *docTitle, char *cssUrl,
   _generate (" ");
   _generate (VERSION);
   _generate( "\nby Lorenzo Bettini, bettini@gnu.org" ) ;
-  _generate( "\nhttp://w3.newnet.it/bettini" ) ;
+  _generate( "\nhttp://www.lorenzobettini.it" ) ;
   _generate( "\nhttp://www.gnu.org/software/src-highlite" ) ;
   _generateln( "\">" ) ;
   _generate( "<title>" ) ;
@@ -233,6 +243,56 @@ void print_bottom( const char *docFooter) {
   _generateln( "</html>" ) ;
 }
 
+void
+print_xtop( char *docTitle, char *cssUrl,
+           const char *docHeader, char *inputFileName)
+{
+  if( cssUrl == 0 ) {
+    _generateln( "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML//EN\">" ) ;
+  }
+  else {
+    _generateln( "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0Transitional//EN\"");
+    _generateln( " \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">");
+  }
+  _generateln( "<html>" ) ;
+  _generateln( "<head>" ) ;
+  _generateln( "<meta http-equiv=\"Content-Type\"" ) ;
+  _generateln( " content=\"text/html; charset=iso-8859-1\" />" ) ;
+  _generate( "<meta name=\"GENERATOR\" content=\"GNU " ) ;
+  _generate (PACKAGE);
+  _generate (" ");
+  _generate (VERSION);
+  _generate( "\nby Lorenzo Bettini, bettini@gnu.org" ) ;
+  _generate( "\nhttp://www.lorenzobettini.it" ) ;
+  _generate( "\nhttp://www.gnu.org/software/src-highlite" ) ;
+  _generateln( "\" />" ) ;
+  _generate( "<title>" ) ;
+  _generate( ( docTitle ? docTitle : 
+              ( inputFileName ? inputFileName : "source file" ) ) ) ;
+  _generateln( "</title>" ) ;
+  if( cssUrl != 0 ) {
+    _generate( "<link rel=\"stylesheet\" href=\"" );
+    _generate( cssUrl );
+    _generateln( "\" type=\"text/css\" />");
+  }
+  _generateln( "</head>" ) ;
+  if( cssUrl == 0 && docHeader == 0) {
+    _generate ("<body style=\"background-color: #FFFFFF; color: #000000; a: #0000EE; ");
+    _generateln ( "a.visited: #551A8B; a.active: #FF0000\">" );
+  }
+  else {
+    _generateln( "<body>" ) ;
+  }
+  if (docHeader)
+    _generateln (docHeader) ;
+}
+
+void print_xbottom( const char *docFooter) {
+  if ( docFooter ) _generateln( docFooter ) ;
+  _generateln( "</body>" ) ;
+  _generateln( "</html>" ) ;
+}
+
 // for generating header and footer
 void
 _generate( const char *s )
@@ -382,10 +442,4 @@ void endTAG( const char *tag ) {
   (*sout) << "</" << tag << ">" ;
 }
 
-void startColor( const char *color ) {
-  startTAG( FONT_TAG, COLOR_TAG, color ) ;
-}
 
-void endColor() {
-  endTAG( FONT_TAG ) ;
-}
