@@ -1,7 +1,7 @@
 #ifndef GLOBALOSTREAM_H
 #define GLOBALOSTREAM_H
 
-#include <ostream.h>
+#include <iostream.h>
 
 extern ostream* sout;
 
