@@ -5,7 +5,7 @@
 #define LESS_THAN "&lt;"
 #define GREATER_THAN "&gt;"
 #define AMPERSAND "&amp;"
-#define NEWLINE "<br>"
+//#define NEWLINE "<br>" for xhtml should be "<br />"
 #define SPACE_CHAR " "
 
 #define FONT_TAG "font"
@@ -18,6 +18,13 @@
 #define ISITALIC 0x2
 #define ISUNDERLINE 0x4
 
+#define SPAN_TAG "span"
+#define XHTML_BOLD_TAG "font-weight"
+#define XHTML_ITALIC_TAG "font-style"
+#define XHTML_UNDERLINE_TAG "text-decoration"
+#define XHTML_BOLD_VAL "bold"
+#define XHTML_ITALIC_VAL "italic"
+#define XHTML_UNDERLINE_VAL "underline"
 
 #include "colors.h"
 
